@@ -8,6 +8,10 @@
 //===----------------------------------------------------------------------===//
 
 // UNSUPPORTED: libcpp-no-exceptions
+
+// This test fails due to a stack overflow
+// XFAIL: LIBCXX-WINDOWS-FIXME
+
 // <exception>
 
 // class nested_exception;
@@ -43,15 +47,22 @@ class C
 {
 public:
 	virtual ~C() {}
-	C * operator&() const { assert(false); } // should not be called
+	C * operator&() const { assert(false); return nullptr; } // should not be called
 };
 
+class D : private std::nested_exception {};
+
+
+class E1 : public std::nested_exception {};
+class E2 : public std::nested_exception {};
+class E : public E1, public E2 {};
+
 int main()
 {
     {
         try
         {
-            A a(3);
+            A a(3);  // not a polymorphic type --> no effect
             std::rethrow_if_nested(a);
             assert(true);
         }
@@ -60,6 +71,30 @@ int main()
             assert(false);
         }
     }
+    {
+        try
+        {
+            D s;  // inaccessible base class --> no effect
+            std::rethrow_if_nested(s);
+            assert(true);
+        }
+        catch (...)
+        {
+            assert(false);
+        }
+    }
+    {
+        try
+        {
+            E s;  // ambiguous base class --> no effect
+            std::rethrow_if_nested(s);
+            assert(true);
+        }
+        catch (...)
+        {
+            assert(false);
+        }
+    }
     {
         try
         {
