@@ -7,6 +7,8 @@
 //
 //===----------------------------------------------------------------------===//
 
+// UNSUPPORTED: c++98, c++03
+
 // <initializer_list>
 
 // template<class E> const E* begin(initializer_list<E> il);
@@ -17,8 +19,6 @@
 
 #include "test_macros.h"
 
-#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
-
 struct A
 {
     A(std::initializer_list<int> il)
@@ -49,13 +49,10 @@ struct B
 };
 
 #endif  // TEST_STD_VER > 11
-#endif  // _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
 
 int main()
 {
-#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
     A test1 = {3, 2, 1};
-#endif
 #if TEST_STD_VER > 11
     constexpr B test2 = {3, 2, 1};
 #endif  // TEST_STD_VER > 11
